# Mapel-core
This package contains the necessary core parts of the mapel ecosystem. Mapel can
be used to draw maps of different kinds of computational problem instances based
on metrices defining distances between two instances.

This package provides the framework that can be further extended. Some of the
extensions, regarding problems for Computational Social Choice, are already
available on PyPi:
1. [mapel-elections](https://pypi.org/project/mapel-elections/)
1. [mapel-roommates](https://pypi.org/project/mapel-rommmates/)
1. [mapel-marriages](https://pypi.org/project/mapel-marriages/)


For the most recent version of mapel, visit its [git
repo](https://github.com/szufix/mapel).

# Installation
For a simple installation, type:
`pip install mapel-core`  
in the console.

# Acknowledgments

This project is part of the [PRAGMA project](https://home.agh.edu.pl/~pragma/)
which has received funding from the [European Research Council
(ERC)](https://home.agh.edu.pl/~pragma/) under the European Union’s Horizon 2020
research and innovation programme ([grant agreement No
101002854](https://erc.easme-web.eu/?p=101002854)).



